from __future__ import print_function
try:
    from flask.ext.babel import gettext as gettext_original, ngettext as ngettext_original
    from flask import current_app
except ImportError:
    print("Flask-Babel is required.")

class Phrase(object):

    def __init__(self, app=None):
        self.app = app
        app.jinja_env.install_gettext_callables(
            gettext,
            ngettext,
            newstyle=True
        )

def phrase_enabled():
    return current_app.config['PHRASEAPP_ENABLED']

def phrase_key(msgid):
    return current_app.config['PHRASEAPP_PREFIX'] + 'phrase_' + msgid + current_app.config['PHRASEAPP_SUFFIX']

def gettext(msgid):
    if phrase_enabled():
        return phrase_key(msgid)
    else:
        return gettext_original(msgid)

def ngettext(msgid):
    if phrase_enabled():
        return phrase_key(msgid)
    else:
        return ngettext_original(msgid)



"""
Flask-Phrase
------------

Connect your Flask apps to PhraseApp, the powerful in-context-translation solution.

"""

from setuptools import setup

setup(
    name='Flask-Phrase',
    version='1.0.0',
    url='http://github.com/phrase/Flask-Phrase',
    license='BSD',
    author='Kevin Kennell',
    author_email='kevin.kennell@dynport.de',
    description='Connect your Flask apps to PhraseApp, the powerful in-context-translation solution.',
    packages=['flask_phrase'],
    zip_safe=False,
    include_package_data=True,
    platforms='any',
    install_requires=[
        'Flask-Babel'
    ],
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Software Development :: Internationalization',
        'Topic :: Software Development :: Localization'
    ]
)
